#!/usr/local/bin/perl -w
print "1..8\n";
require Mail::Address;
print "ok 1\n";
require Mail::Cap;
print "ok 2\n";
require Mail::Field;
print "ok 3\n";
require Mail::Header;
print "ok 4\n";
require Mail::Internet;
print "ok 5\n";
require Mail::Mailer;
print "ok 6\n";
require Mail::Send;
print "ok 7\n";
require Mail::Util;
print "ok 8\n";

